@@ -84,14 +84,19 @@ public class UserAdapter implements User {
         return delegate.getPasswordMech();
     }
 
+    @Override
+    public byte[] getSalt() {
+        return delegate.getSalt();
+    }
+
     @Override
     public int getId() {
-        return delegate.getId();
+        return delegate.getId().intValue();
     }
 
     @Override
     public boolean isMailEnabled() {
-        return delegate.getMailenabled();
+        return delegate.getMailenabled().booleanValue();
     }
 
     @Override
