@@ -50,6 +50,7 @@
 package com.openexchange.admin.storage.utils;
 
 import static com.openexchange.database.DBPoolingExceptionCodes.NOT_RESOLVED_SERVER;
+import static com.openexchange.java.Autoboxing.I;
 import java.sql.Connection;
 import java.sql.DatabaseMetaData;
 import java.sql.PreparedStatement;
@@ -392,7 +393,7 @@ public class Filestore2UserUtil {
      */
     public static void addFilestore2UserEntry(int contextId, int userId, int filestoreId, AdminCacheExtended cache) throws StorageException {
         Connection con = null;
-        boolean rollback = false;
+        int rollback = 0;
         try {
             con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
@@ -407,14 +408,14 @@ public class Filestore2UserUtil {
 
             // Start database transaction
             Databases.startTransaction(con);
-            rollback = true;
+            rollback = 1;
 
             // Insert entry
             insertEntry(new FilestoreEntry(contextId, userId, filestoreId), con);
 
             // Commit
             con.commit();
-            rollback = false;
+            rollback = 2;
         } catch (PoolException e) {
             throw new StorageException(e);
         } catch (SQLException e) {
@@ -423,10 +424,12 @@ public class Filestore2UserUtil {
             throw new StorageException(e);
         } finally {
             if (null != con) {
-                if (rollback) {
-                    Databases.rollback(con);
+                if (rollback > 0) {
+                    if (rollback == 1) {
+                        Databases.rollback(con);
+                    }
+                    Databases.autocommit(con);
                 }
-                Databases.autocommit(con);
                 try {
                     cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
@@ -446,7 +449,7 @@ public class Filestore2UserUtil {
      */
     public static void removeFilestore2UserEntry(int contextId, int userId, AdminCache cache) throws StorageException {
         Connection con = null;
-        boolean rollback = false;
+        int rollback = 0;
         try {
             con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
@@ -461,14 +464,14 @@ public class Filestore2UserUtil {
 
             // Start database transaction
             Databases.startTransaction(con);
-            rollback = true;
+            rollback = 1;
 
             // Insert entry
             deleteEntry(new FilestoreEntry(contextId, userId, 0), con);
 
             // Commit
             con.commit();
-            rollback = false;
+            rollback = 2;
         } catch (PoolException e) {
             throw new StorageException(e);
         } catch (SQLException e) {
@@ -477,10 +480,12 @@ public class Filestore2UserUtil {
             throw new StorageException(e);
         } finally {
             if (null != con) {
-                if (rollback) {
-                    Databases.rollback(con);
+                if (rollback > 0) {
+                    if (rollback == 1) {
+                        Databases.rollback(con);
+                    }
+                    Databases.autocommit(con);
                 }
-                Databases.autocommit(con);
                 try {
                     cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
@@ -499,7 +504,7 @@ public class Filestore2UserUtil {
      */
     public static void removeFilestore2UserEntries(int contextId, AdminCache cache) throws StorageException {
         Connection con = null;
-        boolean rollback = false;
+        int rollback = 0;
         try {
             con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
@@ -514,14 +519,14 @@ public class Filestore2UserUtil {
 
             // Start database transaction
             Databases.startTransaction(con);
-            rollback = true;
+            rollback = 1;
 
             // Insert entry
             deleteEntries(contextId, con);
 
             // Commit
             con.commit();
-            rollback = false;
+            rollback = 2;
         } catch (PoolException e) {
             throw new StorageException(e);
         } catch (SQLException e) {
@@ -530,10 +535,12 @@ public class Filestore2UserUtil {
             throw new StorageException(e);
         } finally {
             if (null != con) {
-                if (rollback) {
-                    Databases.rollback(con);
+                if (rollback > 0) {
+                    if (rollback == 1) {
+                        Databases.rollback(con);
+                    }
+                    Databases.autocommit(con);
                 }
-                Databases.autocommit(con);
                 try {
                     cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
@@ -554,7 +561,7 @@ public class Filestore2UserUtil {
      */
     public static void replaceFilestore2UserEntry(int contextId, int userId, int filestoreId, AdminCacheExtended cache) throws StorageException {
         Connection con = null;
-        boolean rollback = false;
+        int rollback = 0;
         try {
             con = cache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
@@ -569,14 +576,14 @@ public class Filestore2UserUtil {
 
             // Start database transaction
             Databases.startTransaction(con);
-            rollback = true;
+            rollback = 1;
 
             // Insert entry
             replaceEntry(new FilestoreEntry(contextId, userId, filestoreId), con);
 
             // Commit
             con.commit();
-            rollback = false;
+            rollback = 2;
         } catch (PoolException e) {
             throw new StorageException(e);
         } catch (SQLException e) {
@@ -585,10 +592,12 @@ public class Filestore2UserUtil {
             throw new StorageException(e);
         } finally {
             if (null != con) {
-                if (rollback) {
-                    Databases.rollback(con);
+                if (rollback > 0) {
+                    if (rollback == 1) {
+                        Databases.rollback(con);
+                    }
+                    Databases.autocommit(con);
                 }
-                Databases.autocommit(con);
                 try {
                     cache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
@@ -610,7 +619,7 @@ public class Filestore2UserUtil {
      */
     public static void copyFilestore2UserEntry(int contextId, int userId, int destContext, int destUserId, AdminCache adminCache) throws StorageException {
         Connection con = null;
-        boolean rollback = false;
+        int rollback = 0;
         try {
             con = adminCache.getWriteConnectionForConfigDB();
             if (false == tableExists(con, "filestore2user")) {
@@ -625,7 +634,7 @@ public class Filestore2UserUtil {
 
             // Start database transaction
             Databases.startTransaction(con);
-            rollback = true;
+            rollback = 1;
 
             int filestoreId = selectEntry(new FilestoreEntry(contextId, userId, 0), con);
 
@@ -636,7 +645,7 @@ public class Filestore2UserUtil {
 
             // Commit
             con.commit();
-            rollback = false;
+            rollback = 2;
         } catch (PoolException e) {
             throw new StorageException(e);
         } catch (SQLException e) {
@@ -645,10 +654,12 @@ public class Filestore2UserUtil {
             throw new StorageException(e);
         } finally {
             if (null != con) {
-                if (rollback) {
-                    Databases.rollback(con);
+                if (rollback > 0) {
+                    if (rollback == 1) {
+                        Databases.rollback(con);
+                    }
+                    Databases.autocommit(con);
                 }
-                Databases.autocommit(con);
                 try {
                     adminCache.pushWriteConnectionForConfigDB(con);
                 } catch (PoolException e) {
@@ -745,6 +756,8 @@ public class Filestore2UserUtil {
         }
     }
 
+    /*-
+     *
     private static List<Integer> getRegisteredServersIDs(Connection con) throws StorageException {
         PreparedStatement stmt = null;
         ResultSet rs = null;
@@ -767,6 +780,8 @@ public class Filestore2UserUtil {
             Databases.closeSQLStuff(rs, stmt);
         }
     }
+     *
+     */
 
     private static List<SchemaInfo> getAllNonEmptySchemas(Connection con) throws OXException {
         // Determine all DB schemas that are currently in use
@@ -861,11 +876,11 @@ public class Filestore2UserUtil {
                             }
 
                             if (doThrow) {
-                                LOG.error("Failed to determine user-associated file storages for schema \"" + schema.getSchema() + "\" in database " + schema.getPoolId(), e);
+                                LOG.error("Failed to determine user-associated file storages for schema \"{}\" in database {}", schema.getSchema(), I(schema.getPoolId()), e);
                                 throw new StorageException(e);
                             }
                         } catch (SQLException e) {
-                            LOG.error("Failed to determine user-associated file storages for schema \"" + schema.getSchema() + "\" in database " + schema.getPoolId(), e);
+                            LOG.error("Failed to determine user-associated file storages for schema \"{}\" in database 1}", schema.getSchema(), I(schema.getPoolId()), e);
                             throw new StorageException(e);
                         } finally {
                             Databases.closeSQLStuff(result, stmt);
