@@ -326,13 +326,9 @@ public abstract class FilestoreDataMover implements Callable<Void> {
         preDoCopy();
 
         Throwable thrown = null;
-        boolean successful = false;
         try {
             // Do the copy
             doCopy(new URI(srcFilestore.getUrl()), new URI(dstFilestore.getUrl()));
-
-            // Successfully performed
-            successful = true;
         } catch (URISyntaxException e) {
             thrown = e; throw new StorageException(e.getMessage(), e);
         } catch (RuntimeException e) {
@@ -486,22 +482,24 @@ public abstract class FilestoreDataMover implements Callable<Void> {
         }
         int contextId = ctx.getId().intValue();
         Connection con = Database.getNoTimeout(contextId, true);
-        boolean rollback = false;
+        int rollback = 0;
         try {
             Databases.startTransaction(con);
-            rollback = true;
+            rollback = 1;
 
             for (FileLocationHandler updater : FilestoreLocationUpdaterRegistry.getInstance().getServices()) {
                 updater.updateFileLocations(prevFileName2newFileName, contextId, con);
             }
 
             con.commit();
-            rollback = false;
+            rollback = 2;
         } finally {
-            if (rollback) {
-                Databases.rollback(con);
+            if (rollback > 0) {
+                if (rollback == 1) {
+                    Databases.rollback(con);
+                }
+                Databases.autocommit(con);
             }
-            Databases.autocommit(con);
             Database.backNoTimeout(contextId, true, con);
         }
     }
@@ -564,6 +562,7 @@ public abstract class FilestoreDataMover implements Callable<Void> {
      *
      * @throws StorageException If pre-copy operations fails
      */
+    @SuppressWarnings("unused")
     protected void preDoCopy() throws StorageException {
         // Initially empty
     }
@@ -573,7 +572,7 @@ public abstract class FilestoreDataMover implements Callable<Void> {
      *
      * @param thrown The {@link Throwable} instance in case an error occurred; otherwise <code>null</code>
      */
-    protected void postDoCopy(Throwable thrown) {
+    protected void postDoCopy(@SuppressWarnings("unused") Throwable thrown) {
         // Initially empty
     }
 
@@ -701,26 +700,28 @@ public abstract class FilestoreDataMover implements Callable<Void> {
     protected static void changeUsage(DecrementUsage decUsage, IncrementUsage incUsage, int contextId) throws StorageException {
         AdminCache cache = ClientAdminThread.cache;
         Connection con = null;
-        boolean rollback = false;
+        int rollback = 0;
         try {
             con = cache.getConnectionForContext(contextId);
             Databases.startTransaction(con);
-            rollback = true;
+            rollback = 1;
 
             doDecUsage(decUsage.decrementUsage, decUsage.ownerId, contextId, con);
             doIncUsage(incUsage.incrementUsage, incUsage.ownerId, contextId, con);
 
             con.commit();
-            rollback = false;
+            rollback = 2;
         } catch (PoolException e) {
             throw new StorageException(e);
         } catch (SQLException e) {
             throw new StorageException(e);
         } finally {
-            if (rollback) {
-                Databases.rollback(con);
+            if (rollback > 0) {
+                if (rollback == 1) {
+                    Databases.rollback(con);
+                }
+                Databases.autocommit(con);
             }
-            Databases.autocommit(con);
 
             if (null != con) {
                 try {
